/*////////////////////////////////////////////////////////////////////////////
    PROJECT:    APRS Transmitter
    COPYRIGHT    2010 Dean J. Boman

    FILE:       serial.c
    AUTHOR:     Dean J. Boman

    OVERVIEW:
        Implementation of the serial interface 

    REVISION HISTORY:

    Jan. 25, 2010	Initial development




*/////////////////////////////////////////////////////////////////////////////

#include "..\Include\Compiler.h"
#include "..\Include\typedef.h"
#include "..\Include\serial.h"

uint8 SerialFIFO[128];
uint8 SerialHead;
uint8 SerialTail;


/**
	Initialize the serial FIFO

  
	@return void

*/
void SerialInit(void)
{
	SerialHead = 0;
	SerialTail = 0;
}

/**

	Read a byte from the serial FIFO if it is ready.  If data is not ready zero is returned

	@return uint8 Serial data byte

*/
uint8 SerialRead(void)
{
	uint8 DataValue;

	//Cover the case where there is no data in the FIFO.  Should never occur.
	if(SerialHead == SerialTail)
		return 0;

	DataValue = SerialFIFO[SerialTail];

	//Adjust the tail forward by one location.  Wrap around at the end of the buffer
	SerialTail = (SerialTail + 1) & 0x7f;

	return DataValue;
}


/**

	Determine if the FIFO has data ready

	@return boolean - TRUE if data is ready

*/
boolean SerialIsDataReady(void)
{
	if(SerialHead != SerialTail)
		return TRUE;

	return FALSE;
}



/**

	Serial data is read in the hardware so read it and put it into the FIFO

	@return boolean - TRUE if FIFO overrun has occured

*/
boolean SerialProcess(void)
{
	//Data is available
	if((RCSTAbits.OERR) == 0x01)
	{
		//Overrun error.  Disable the receiver and re-enable to clear
		RCSTAbits.CREN = 0;
		RCSTAbits.CREN = 1;
		return TRUE;
	}
	else
	{
		//Read data and save to the FIFO
		SerialFIFO[SerialHead] = RCREG;
	
		//Increment the pointer and wrap around if necessary
		SerialHead = (SerialHead + 1) & 0x7f;

		if(SerialHead == SerialTail) 
			return TRUE;
	}

	return FALSE;

}

