/**
  ******************************************************************************
  * @file    i2c.h
  * @author  D. Erickson
  * @version V0.0
  * @date    03/11/2011
  * @brief   This file contains all the I2C controls, from the low level to the
  * 		 device handlers for each function.
  ******************************************************************************
  * @copy
  *
  *
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __I2C_H
#define __I2C_H

/* Includes ------------------------------------------------------------------*/
//#include "stm32_eval.h"
#include "stm32f10x.h"

 /** @addtogroup STM3210C_EVAL_LOW_LEVEL_I2C_EE
   * @{
   */
 /**
   * @brief  I2C EEPROM Interface pins
   */
 #define pre_I2C                    I2C1
 #define pre_I2C_CLK                RCC_APB1Periph_I2C1
 #define pre_I2C_SCL_PIN           	GPIO_Pin_6                  /* PB.06 */
 #define pre_I2C_SCL_GPIO_PORT     	GPIOB                       /* GPIOB */
 #define pre_I2C_SCL_GPIO_CLK      	RCC_APB2Periph_GPIOB
 #define pre_I2C_SDA_PIN           	GPIO_Pin_7                  /* PB.07 */
 #define pre_I2C_SDA_GPIO_PORT     	GPIOB                       /* GPIOB */
 #define pre_I2C_SDA_GPIO_CLK      	RCC_APB2Periph_GPIOB
 #define pre_M24C64_32
 #define I2C_SLAVE_ADDRESS7     	0xA0

/* DMA is not used */
 #define pre_I2C_DMA              	DMA1
 #define pre_I2C_DMA_CHANNEL_TX    	DMA1_Channel6
 #define pre_I2C_DMA_CHANNEL_RX   	DMA1_Channel7
 #define pre_I2C_DMA_FLAG_TX_TC   	DMA1_IT_TC6
 #define pre_I2C_DMA_FLAG_TX_GL   	DMA1_IT_GL6
 #define pre_I2C_DMA_FLAG_RX_TC   	DMA1_IT_TC7
 #define pre_I2C_DMA_FLAG_RX_GL   	DMA1_IT_GL7
 #define pre_I2C_DMA_CLK            RCC_AHBPeriph_DMA1
 #define pre_I2C_DR_Address        	((uint32_t)0x40005410)
 #define pre_USE_DMA

 #define pre_I2C_DMA_TX_IRQn       	DMA1_Channel6_IRQn
 #define pre_I2C_DMA_RX_IRQn       	DMA1_Channel7_IRQn
 #define pre_I2C_DMA_TX_IRQHandler	DMA1_Channel6_IRQHandler
 #define pre_I2C_DMA_RX_IRQHandler  DMA1_Channel7_IRQHandler
 #define pre_I2C_DMA_PREPRIO       	0
 #define pre_I2C_DMA_SUBPRIO       	0

 #define pre_DIRECTION_TX          	0
 #define pre_DIRECTION_RX          	1

 /* I2C address table and device types */
 #define I2C_XPT_ADDR 	0x40		/* MCP32008 */
 #define I2C_PRESEL0 	0x44		/* MCP32008 */
 #define I2C_PRESEL1 	0x46		/* MCP32008 */
 #define I2C_KPAD_ADDR 	0x48		/* PCA8574 */
 #define I2C_TDA7439 	0x88		/* TDA7439 */

 #define I2C_SPEED      400000

/* Defines for MCP32008 Registers */
 #define M23008_DIR		0x00
 #define M23008_IOCON 	0x05
 #define M23008_GPIO	0x09
 #define M23008_OLAT	0x0A

/* Defines for crosspoint control bits */
 #define XPT_SRC 		0x38    /* Bits 5:3 */
 #define XPT_ZONE 		0x07	/* Bits 2:0, 3 LSBs*/
 #define XTB_ST_ON 		0x40	/* Bit 6 */
 #define XTB_ST_OFF 	0x00
 #define XTB_DON 		0x80	/* Bit 7 */
 #define XTB_DOFF		0x00

 /* TDA7439 Registers */
 #define TDA7439_INSEL	0x00
 #define TDA7439_INGAIN	0x01
 #define TDA7439_VOL	0x02
 #define TDA7439_BASS	0x03
 #define TDA7439_MID	0x04
 #define TDA7439_TREB	0x05
 #define TDA7439_SPR	0x06
 #define TDA7439_SPL	0x07

 #define TDA7439_MUTE	0x38
 #define TDA7439_IN1	0x03

/* Maximum timeout value for counting before exiting waiting loop on DMA
   Transfer Complete. This value depends directly on the maximum page size and
   the system clock frequency. */
 #define pre_TIMEOUT_MAX         0x10000;

/** @defgroup STM32_EVAL_I2C_EE_Exported_Functions
  * @{
  */
void preamp_i2c_DeInit(void);
void preamp_i2c_Init(void);
void i2c_Write(uint8_t addr, uint8_t* buffer, uint8_t count);
void i2c_LowLevel_Init(void);
void xpt_set(uint8_t zone, uint8_t old, uint8_t new);
void xpt_init();
void MCP23008_init(uint8_t device);
void TDA7439_write(uint8_t reg, uint8_t data);
void preamp_set(uint8_t zone);
void preamp_init(void);
uint8_t toneScale(int8_t tone);

#endif /* __I2C_H */



